from db import create_session
from models import *
session = create_session()
cc = session.query(CC.CC).first()
att = session.query(Attendance.Attendance).first()
sec = session.query(Section.Section).first()
test = session.query(Test.Test).first()
print(test.test_scores)


from pprint import pformat

from sqlalchemy import (Boolean, Column, Date, Float, ForeignKey,
                        ForeignKeyConstraint, Integer, MetaData, String, Table)
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import relationship
from .StudentTest import StudentTest
from .base import Base

class StudentTestScore(Base):
    __tablename__ = 'studenttestscore'
    __table_args__ = (
        ForeignKeyConstraint(
            ['studenttestid'],
            ['studenttest.id']
        ),
        ForeignKeyConstraint(
            ['testscoreid'],
            ['testscore.id']
        ),
    )

    id = Column(Integer)
    dcid = Column(Integer, primary_key=True)
    test_score_id = Column('testscoreid', Integer)
    student_test_id = Column('studenttestid', Integer)
    alpha_score = Column('alphascore', String)
    num_score = Column('numscore', Float)
    percent_score = Column('percentscore', Float)

    student_test = relationship(
        'StudentTest', back_populates='student_test_scores')
    test_score = relationship('TestScore')

    def __repr__(self):
        return 'StudentTestScore: ' + pformat(vars(self))


from pprint import pformat

from sqlalchemy import (Boolean, Column, Date, Float, ForeignKey,
                        ForeignKeyConstraint, Integer, MetaData, String, Table)
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import relationship

from .base import Base

class Period(Base):
    __tablename__ = 'period'
    __table_args__ = (
        ForeignKeyConstraint(
            ['schoolid'],
            ['schools.school_number']
        ),
    )

    dcid = Column(Integer, primary_key=True)
    id = Column(Integer, unique=True)
    school_id = Column('schoolid', Integer)
    school = relationship('School')
    year_id = Column('year_id', Integer)
    period_number = Column(Integer)
    name = Column(String)
    abbreviation = Column(String)

    def __repr__(self):
        return 'Period: ' + pformat(vars(self))


from pprint import pformat
from sqlalchemy import (Boolean, Column, Date, Float, ForeignKey,
                        ForeignKeyConstraint, Integer, MetaData, String, Table)
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import relationship

from .base import Base


class CalendarDay(Base):
    __tablename__ = 'calendar_day'

    id = Column(Integer)
    dcid = Column(Integer, primary_key=True)
    date_value = Column(Date)
    school_id = Column('schoolid', Integer)
    in_session = Column('insession', Boolean)

    def __repr__(self):
            return 'CalendarDay: ' + pformat(vars(self))



from pprint import pformat

from sqlalchemy import (Boolean, Column, Date, Float, ForeignKey,
                        ForeignKeyConstraint, Integer, MetaData, String, Table)
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import relationship

from .Term import Term
from .base import Base

class Course(Base):
    __tablename__ = 'courses'
    dcid = Column(Integer, primary_key=True)
    name = Column('course_name', String)
    code = Column(String)
    number = Column('course_number', String)

    def __repr__(self):
        return 'Course: ' + pformat(vars(self))



from pprint import pformat

from sqlalchemy import (Boolean, Column, Date, Float, ForeignKey,
                        ForeignKeyConstraint, Integer, MetaData, String, Table)
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import relationship
from .base import Base

class School(Base):
    __tablename__ = 'schools'

    dcid = Column(Integer, primary_key=True)
    id = Column(Integer, unique=True)
    name = Column(String)
    school_number = Column(String, unique=True)
    
    def __repr__(self):
        return 'School: ' + pformat(vars(self))



from setuptools import setup

setup(name='powerschool_alchemy',
      version='0.0.3',
      description='This library allows you to interact with a PowerSchool Database with SQLALchemy, a Python ORM',
      url='https://github.com/IronCountySchoolDistrict/powerschool-alchemy',
      author='Iron County School District',
      author_email='data@ironmail.org',
      license='MIT',
      packages=['powerschool_alchemy'],
      install_requires=[
          'python-dotenv',
          'SQLAlchemy',
          'cx-oracle',
      ],
      zip_safe=False)



from pprint import pformat

from sqlalchemy import (Boolean, Column, Date, Float, ForeignKey,
                        ForeignKeyConstraint, Integer, MetaData, String, Table)
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import relationship

from .base import Base
from .Test import Test

class TestScore(Base):
    __tablename__ = 'testscore'
    __table_args__ = (
        ForeignKeyConstraint(
            ['testid'],
            ['test.id']
        ),
    )

    id = Column(Integer)
    dcid = Column(Integer, primary_key=True)
    test_id = Column('testid', Integer)
    name = Column(String)
    description = Column(String)
    sort_order = Column('sortorder', Integer)

    test = relationship('Test', back_populates='test_scores')

    def __repr__(self):
        return 'TestScore: ' + pformat(vars(self))



from pprint import pformat

from sqlalchemy import (Boolean, Column, Date, Float, ForeignKey,
                        ForeignKeyConstraint, Integer, MetaData, String, Table)
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import relationship
from .School import School
from .base import Base

class Term(Base):
    __tablename__ = 'terms'
    __table_args__ = (
        ForeignKeyConstraint(
            ['schoolid'],
            ['schools.school_number']
        ),
    )

    id = Column(Integer)
    year_id = Column('yearid', Integer)
    name = Column(String)
    dcid = Column(Integer, primary_key=True)
    school_id = Column('schoolid', Integer)
    school = relationship('School')
    first_day = Column('firstday', Date)
    last_day = Column('lastday', Date)
    is_year = Column('isyearrec', Boolean)
    year_id = Column('yearid', Integer)

    def __repr__(self):
        return 'Term: ' + pformat(vars(self))
    